@@ -11,7 +11,7 @@ use warnings;
 #my $VERSION="0.1";
 
 #For CVS , use following line
-our $VERSION=sprintf("%d.%04d", q$Revision: 2008.0407 $ =~ /(\d+)\.(\d+)/);
+our $VERSION=sprintf("%d.%04d", q$Revision: 2008.0501 $ =~ /(\d+)\.(\d+)/);
 
 BEGIN {
 
@@ -27,6 +27,10 @@ BEGIN {
 
 } ## end BEGIN
 
+##
+## Use HTTPS! AtomAPIdoc=http://code.blogger.com/archives/atom-docs.html
+##
+
 require Net::Google::GData;
 
 require WWW::Blogger::Com; ## NOTE: I need WWW::Google secrets
@@ -125,8 +129,11 @@ push( @WWW::Blogger::XML::API::EXPORT_OK,
 ##
 ## NOTE: Getopts hasn't set the options yet. (all flags = 0 right now)
 ##
-
-$WWW::Blogger::XML::API::ua = undef; ## goto qw(ua_request) function
+## I've deferred the instantiation of this qw(ua) until needed.
+## That occurs when creating the xmlrpc request types ( qw(ua->string), etc.).
+## I fixed this problem with qw(ua_central) function.
+##
+$WWW::Blogger::XML::API::ua = undef; ## Frontier::Client see NOTE above, goto qw(ua_central) function
 
 $WWW::Blogger::XML::API::tree = undef;
 
@@ -311,21 +318,19 @@ sub WWW::Blogger::XML::API::demo
 
    my $xml_tree = undef;
 
-   my $blogid = undef;
-
-   $request = WWW::Blogger::XML::API::list_of_blogs_by_userid( 'default' );
+   $request = WWW::Blogger::XML::API::list_of_blogs_by_userid( '10829698745685235014' );
 
    $result = WWW::Blogger::XML::API::ua_request( $request );
 
    if ( $result->is_success() )
    {
-      $blogid = WWW::Blogger::XML::API::parse_list_of_blogs( $result );
+      WWW::Blogger::XML::API::parse_list_of_blogs( $result );
 
    } ## end if
 
-   WWW::Blogger::XML::API::clear_test_posts_by_blogid( $blogid );
+   WWW::Blogger::XML::API::clear_test_posts_by_blogid( '1538373143315425622' );
 
-   $request = WWW::Blogger::XML::API::test_post_by_blogid( $blogid );
+   $request = WWW::Blogger::XML::API::test_post_by_blogid( '1538373143315425622' );
 
    $result = WWW::Blogger::XML::API::ua_request( $request );
 
@@ -336,11 +341,11 @@ sub WWW::Blogger::XML::API::demo
    }
    else
    {
-      print $result->as_string() . "\nFAILURE\n";
+      print $result->as_string() . "\nfailure\n";
 
    } ## end if
 
-   $request = WWW::Blogger::XML::API::list_of_posts_by_blogid( $blogid );
+   $request = WWW::Blogger::XML::API::list_of_posts_by_blogid( '1538373143315425622' );
 
    $result = WWW::Blogger::XML::API::ua_request( $request );
 
@@ -351,7 +356,7 @@ sub WWW::Blogger::XML::API::demo
    }
    else
    {
-      print $result->as_string() . "\nFAILURE\n";
+      print $result->as_string() . "\nfailure\n";
 
    } ## end if
 
@@ -365,11 +370,7 @@ sub WWW::Blogger::XML::API::list_of_blogs_by_userid
 {
    my $userid = shift || 'default';
 
-   my $request = HTTP::Request->new();
-
-   $request->method( 'GET' );
-
-   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${userid}/blogs" );
+   my $request = HTTP::Request->new( 'GET', $WWW::Blogger::XML::API::url . "/feeds/${userid}/blogs" );
 
    return( $request );
 
@@ -382,8 +383,6 @@ sub WWW::Blogger::XML::API::parse_list_of_blogs
 {
    my $result = shift;
 
-   my $blogid = undef; ## returning for demonstration purposes
-
    my $xml_tree = XML::TreeBuilder->new(); 
 
    $xml_tree->parse( $result->content() );
@@ -400,8 +399,6 @@ sub WWW::Blogger::XML::API::parse_list_of_blogs
 
          $xml_id->content()->[ 0 ] =~ m/[:]user[-](\d+)[.]blog[-](\d+)/;
 
-         $blogid = $2 if ( ! defined( $blogid ) ); ## returning first for demonstration purposes
-
          ##debug##
          printf( "user=%s\tblogid=%s\n", $1, $2 );
 
@@ -445,8 +442,6 @@ sub WWW::Blogger::XML::API::parse_list_of_blogs
 
    $xml_tree->delete();
 
-   return( $blogid );
-
 } ## end sub WWW::Blogger::XML::API::parse_list_of_blogs
 
 ##
@@ -492,8 +487,15 @@ sub WWW::Blogger::XML::API::test_post_by_blogid
    ##
    ## Request
    ##
+   my $request = HTTP::Request->new();
 
-   my $request = WWW::Blogger::XML::API::post_entry_by_blogid( $blogid, $entry );
+   $request->method( 'POST' );
+
+   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${blogid}/posts/default" );
+
+   $request->header( 'Content_Type' => 'application/atom+xml' );
+
+   $request->content( $entry->as_xml() );
 
    return( $request );
 
@@ -523,8 +525,8 @@ sub WWW::Blogger::XML::API::parse_test_post_entry
    ##
    my $request = WWW::Blogger::XML::API::test_comment_by_blogid_postid( $1, $2 );
 
-   $result = WWW::Blogger::XML::API::ua_request( $request ); #1
-   $result = WWW::Blogger::XML::API::ua_request( $request ); #2
+   $result = WWW::Blogger::XML::API::ua_request( $request );
+   $result = WWW::Blogger::XML::API::ua_request( $request );
 
    $xml_tree->delete();
 
@@ -544,11 +546,7 @@ sub WWW::Blogger::XML::API::list_of_posts_by_blogid
 {
    my $blogid = shift;
 
-   my $request = HTTP::Request->new();
-
-   $request->method( 'GET' );
-
-   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${blogid}/posts/default" );
+   my $request = HTTP::Request->new( 'GET', $WWW::Blogger::XML::API::url . "/feeds/${blogid}/posts/default" );
 
    return( $request );
 
@@ -622,27 +620,6 @@ sub WWW::Blogger::XML::API::parse_list_of_posts
 
 } ## end sub WWW::Blogger::XML::API::parse_list_of_posts
 
-##
-## Creating a post entry
-##
-sub WWW::Blogger::XML::API::post_entry_by_blogid
-{
-   my ( $blogid, $entry ) = @_;
-
-   my $request = HTTP::Request->new();
-
-   $request->method( 'POST' );
-
-   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${blogid}/posts/default" );
-
-   $request->header( 'Content_Type' => 'application/atom+xml' );
-
-   $request->content( $entry->as_xml() );
-
-   return( $request );
-
-} ## end sub WWW::Blogger::XML::API::post_entry_by_blogid
-
 ##
 ## Modifying a post entry
 ##
@@ -655,17 +632,11 @@ sub WWW::Blogger::XML::API::post_entry_by_blogid
 ##
 ## Retrieve a post entry
 ##
-## GET http://www.blogger.com/feeds/blogID/posts/default/postID
-##
 sub WWW::Blogger::XML::API::get_post_by_blogid_postid
 {
    my ( $blogid, $postid ) = @_;
 
-   my $request = HTTP::Request->new();
-
-   $request->method( 'GET' );
-
-   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${blogid}/posts/default/${postid}" );
+   my $request = HTTP::Request->new( 'GET', $WWW::Blogger::XML::API::url . "/feeds/${blogid}/posts/default/${postid}" );
 
    return( $request );
 
@@ -674,21 +645,11 @@ sub WWW::Blogger::XML::API::get_post_by_blogid_postid
 ##
 ## Updating a post entry
 ##
-## PUT http://www.blogger.com/feeds/blogID/posts/default/postID
-##
 sub WWW::Blogger::XML::API::put_post_by_blogid_postid
 {
-   my ( $blogid, $postid, $entry ) = @_;
+   my ( $blogid, $postid ) = @_;
 
-   my $request = HTTP::Request->new();
-
-   $request->method( 'PUT' );
-
-   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${blogid}/posts/default/${postid}" );
-
-   $request->header( 'Content_Type' => 'application/atom+xml' );
-
-   $request->content( $entry->as_xml() );
+   my $request = HTTP::Request->new( 'PUT', $WWW::Blogger::XML::API::url . "/feeds/${blogid}/posts/default/${postid}" );
 
    return( $request );
 
@@ -703,11 +664,7 @@ sub WWW::Blogger::XML::API::remove_post_by_blogid_postid
 {
    my ( $blogid, $postid ) = @_;
 
-   my $request = HTTP::Request->new();
-
-   $request->method( 'DELETE' );
-
-   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${blogid}/posts/default/${postid}" );
+   my $request = HTTP::Request->new( 'DELETE', $WWW::Blogger::XML::API::url . "/feeds/${blogid}/posts/default/${postid}" );
 
    return( $request );
 
@@ -725,33 +682,8 @@ sub WWW::Blogger::XML::API::remove_post_by_blogid_postid
 ## new POST request, using the application/atom+xml content type.
 ## Then send the POST request to the appropriate Blogger URL:
 ##
-
-##
-## Creating a comment entry
-##
 ## POST http://www.blogger.com/feeds/blogID/postID/comments/default
 ##
-sub WWW::Blogger::XML::API::comment_entry_by_blogid_postid
-{
-   my ( $blogid, $postid, $entry ) = @_;
-
-   my $request = HTTP::Request->new();
-
-   $request->method( 'POST' );
-
-   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${blogid}/${postid}/comments/default" );
-
-   $request->header( 'Content_Type' => 'application/atom+xml' );
-
-   $request->content( $entry->as_xml() );
-
-   return( $request );
-
-} ## end sub WWW::Blogger::XML::API::comment_entry_by_blogid
-
-##
-## Test comment
-##
 sub WWW::Blogger::XML::API::test_comment_by_blogid_postid
 {
    my ( $blogid, $postid ) = @_;
@@ -783,7 +715,15 @@ sub WWW::Blogger::XML::API::test_comment_by_blogid_postid
    ##
    ## Request
    ##
-   my $request = WWW::Blogger::XML::API::comment_entry_by_blogid_postid( $blogid, $postid, $entry );
+   my $request = HTTP::Request->new();
+
+   $request->method( 'POST' );
+
+   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${blogid}/${postid}/comments/default" );
+
+   $request->header( 'Content_Type' => 'application/atom+xml' );
+
+   $request->content( $entry->as_xml() );
 
    return( $request );
 
@@ -791,18 +731,13 @@ sub WWW::Blogger::XML::API::test_comment_by_blogid_postid
 
 ##
 ## Retrieving all comments for a blog
-##
 ## GET http://www.blogger.com/feeds/blogID/comments/default
 ##
 sub WWW::Blogger::XML::API::list_of_comments_by_blogid
 {
    my $blogid = shift;
 
-   my $request = HTTP::Request->new();
-
-   $request->method( 'GET' );
-
-   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${blogid}/comments/default" );
+   my $request = HTTP::Request->new( 'GET', $WWW::Blogger::XML::API::url . "/feeds/${blogid}/comments/default" );
 
    return( $request );
 
@@ -810,44 +745,20 @@ sub WWW::Blogger::XML::API::list_of_comments_by_blogid
 
 ##
 ## Retrieving comments for a particular post
-##
 ## GET http://www.blogger.com/feeds/blogID/postID/comments/default
 ##
 sub WWW::Blogger::XML::API::list_of_comments_by_blogid_postid
 {
    my ( $blogid, $postid ) = @_;
 
-   my $request = HTTP::Request->new();
-
-   $request->method( 'GET' );
-
-   $request->uri( $WWW::Blogger::XML::API::url .  "/feeds/${blogid}/${postid}/comments/default" );
+   my $request = HTTP::Request->new( 'GET', $WWW::Blogger::XML::API::url .  "/feeds/${blogid}/${postid}/comments/default" );
 
    return( $request );
 
 } ## end sub WWW::Blogger::XML::API::list_of_comments_by_blogid_postid
 
 ##
-## Removing a stray comment (in the undocumented way)
-##
-## DELETE http://www.blogger.com/feeds/blogID/comments/default/commentID
-##
-sub WWW::Blogger::XML::API::remove_comment_by_blogid_commentid
-{
-   my ( $blogid, $commentid ) = @_;
-
-   my $request = HTTP::Request->new();
-
-   $request->method( 'DELETE' );
-
-   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${blogid}/comments/default/${commentid}" );
-
-   return( $request );
-
-} ## end sub WWW::Blogger::XML::API::remove_comment_by_blogid_commentid
-
-##
-## Removing a comment (in the standard way)
+## Removing a comment
 ##
 ## DELETE http://www.blogger.com/feeds/blogID/postID/comments/default/commentID
 ##
@@ -855,11 +766,7 @@ sub WWW::Blogger::XML::API::remove_comment_by_blogid_postid_commentid
 {
    my ( $blogid, $postid, $commentid ) = @_;
 
-   my $request = HTTP::Request->new();
-
-   $request->method( 'DELETE' );
-
-   $request->uri( $WWW::Blogger::XML::API::url . "/feeds/${blogid}/${postid}/comments/default/${commentid}" );
+   my $request = HTTP::Request->new( 'DELETE', $WWW::Blogger::XML::API::url . "/feeds/${blogid}/${postid}/comments/default/${commentid}" );
 
    return( $request );
 
@@ -888,10 +795,6 @@ sub WWW::Blogger::XML::API::clear_test_comments_by_blogid_postid
       {
          foreach my $xml_entry ( $xml_tree->find_by_tag_name( 'entry' ) ) ## comment entries
          {
-            my $xml_content = $xml_entry->find_by_tag_name( 'content' );
-
-            next if ( $xml_content->content()->[ 0 ] ne 'This is a test comment.' );
-
             my $xml_id = $xml_entry->find_by_tag_name( 'id' );
 
             $xml_id->content()->[ 0 ] =~ m/[:]blog[-](\d+)[.]post[-](\d+)/; ## commentid
@@ -935,10 +838,6 @@ sub WWW::Blogger::XML::API::clear_test_posts_by_blogid
       {
          foreach my $xml_entry ( $xml_tree->find_by_tag_name( 'entry' ) ) ## post entries
          {
-            my $xml_title = $xml_entry->find_by_tag_name( 'title' );
-
-            next if ( $xml_title->content()->[ 0 ] ne 'Test Post' );
-
             my $xml_id = $xml_entry->find_by_tag_name( 'id' );
 
             $xml_id->content()->[ 0 ] =~ m/[:]blog[-](\d+)[.]post[-](\d+)/; ## postid
@@ -978,6 +877,10 @@ http://code.google.com/apis/blogger/developers_guide_protocol.html
 
  my $result = WWW::Blogger::XML::API::ua_request( $request );
 
+ Options;
+
+   --xml_api_*
+
 =head1 OPTIONS
 
 --xml_api_*
@@ -1013,24 +916,24 @@ See Example: WWW::Blogger::XML::API::parse_list_of_blogs( $result )
 
 =head2	Creating posts
 
-1. Publishing a blog post
-
 =over
 
 $request = WWW::Blogger::XML::API::test_post_by_blogid( $blogid ) ## a Test Post
 
--OR-
-
-$request = WWW::Blogger::XML::API::post_entry_by_blogid( $blogid, $entry );
-
 $result = WWW::Blogger::XML::API::ua_request( $request );
 
-Follow the "Test Post" example to create your XML::Atom::Syndication::Entry.
-
 See Example: WWW::Blogger::XML::API::parse_test_post_entry( $result );
 
 =back
 
+1. Publishing a blog post
+
+=over
+
+Follow the "Test Post" example to create your XML::Atom::Syndication::Entry.
+
+=back
+
 2. Creating a draft blog post
 
 =over
@@ -1091,11 +994,7 @@ $result = WWW::Blogger::XML::API::ua_request( $request );
 
 =over
 
-$request = WWW::Blogger::XML::API::test_comment_by_blogid_postid( $blogid, $postid );
-
--OR-
-
-$request = WWW::Blogger::XML::API::comment_entry_by_blogid_postid( $blogid, $postid, $entry );
+$request = WWW::Blogger::XML::API::test_comment_by_blogid_postid( $blogid, $postid ); ## a Test Comment
 
 $result = WWW::Blogger::XML::API::ua_request( $request );
 
